@@ -245,7 +245,7 @@ pub(crate) enum Command {
 
     /// Creates report from a given VCF file including a visual plot
     /// for every variant with the given BAM and FASTA file.
-    /// The VCF file has to be annotated with VEP, using the options --hgvs, --hgvsg and --vcf_info_field ANN.
+    /// The VCF file has to be annotated with VEP, using the options --hgvs and --hgvsg.
     ///
     /// Examples:
     /// With current directory as default ouput path:
@@ -306,6 +306,10 @@ pub(crate) enum Command {
         #[structopt(long, default_value = "0")]
         threads: usize,
 
+        /// Set the name of the annotation field generated by VEP.
+        #[structopt(long, short = "a", default_value = "ANN")]
+        annotation_field: String,
+
         /// Relative output path for the report files. Default value is the current directory.
         #[structopt(default_value = ".")]
         output_path: String,
